@@ -2,7 +2,7 @@ import json
 from django import forms
 from django.dispatch import receiver
 from django.urls import resolve, reverse
-from django.utils.translation import gettext_noop, ugettext_lazy as _
+from django.utils.translation import gettext_lazy, gettext_noop
 from i18nfield.strings import LazyI18nString
 from pretix.base.settings import settings_hierarkey
 from pretix.base.signals import (
@@ -51,12 +51,14 @@ def add_matrix_id_question(sender, position, **kwargs):
 
     return {
         "matrix_inviter_matrix_id": forms.RegexField(
-            label=_("Matrix ID"),
+            label=gettext_lazy("Matrix ID"),
             required=False,
             regex="@[a-z0-9._=/-]+:[a-z0-9.-]+",
             strip=True,
             error_messages={
-                "invalid": _("Enter a Matrix ID of the form @username:homeserver.tld")
+                "invalid": gettext_lazy(
+                    "Enter a Matrix ID of the form @username:homeserver.tld"
+                )
             },
             help_text=rich_text_snippet(sender.settings.matrix_inviter_hint),
         )
@@ -128,11 +130,11 @@ def matrix_inviter_kick_async(sender, order, **kwargs):
 
 
 @receiver(nav_event_settings, dispatch_uid="matrix_inviter_nav_settings")
-def navbar_settings(sender, request=None, **kwargs):
+def navbar_settings(sender, request, **kwargs):
     url = resolve(request.path_info)
     return [
         {
-            "label": _("Matrix inviter"),
+            "label": gettext_lazy("Matrix inviter"),
             "url": reverse(
                 "plugins:pretix_matrix_inviter:settings",
                 kwargs={
@@ -152,16 +154,16 @@ def logentry_display(sender, logentry, **kwargs):
         return
 
     locales = {
-        "pretix_matrix_inviter.invite_sent": _(
+        "pretix_matrix_inviter.invite_sent": gettext_lazy(
             "{matrix_id} has been invited to {matrix_room}."
         ),
-        "pretix_matrix_inviter.invite_rescinded": _(
+        "pretix_matrix_inviter.invite_rescinded": gettext_lazy(
             "{matrix_id} has been removed from {matrix_room}."
         ),
-        "pretix_matrix_inviter.error": _(
+        "pretix_matrix_inviter.error": gettext_lazy(
             "There was an error inviting {matrix_id} to {matrix_room}: {error}"
         ),
-        "pretix_matrix_inviter.remove_error": _(
+        "pretix_matrix_inviter.remove_error": gettext_lazy(
             "There was an error removing {matrix_id} from {matrix_room}: {error}"
         ),
     }
