@@ -2,13 +2,13 @@ from django.urls import reverse
 from pretix.base.models import Event
 from pretix.control.views.event import EventSettingsFormView, EventSettingsViewMixin
 
-from .forms import MatrixInviterForm
+from .forms import MatrixInviterSettingsForm
 
 
-class MatrixInviterView(EventSettingsViewMixin, EventSettingsFormView):
+class MatrixInviterSettingsView(EventSettingsViewMixin, EventSettingsFormView):
     model = Event
     permission = "can_change_settings"
-    form_class = MatrixInviterForm
+    form_class = MatrixInviterSettingsForm
     template_name = "pretix_matrix_inviter/settings.html"
 
     def get_success_url(self, **kwargs):
